summaryrefslogtreecommitdiff
path: root/src/csplit.c
diff options
context:
space:
mode:
authorJim Meyering <jim@meyering.net>1995-06-24 21:07:55 +0000
committerJim Meyering <jim@meyering.net>1995-06-24 21:07:55 +0000
commit5cd7a18539b3cab460ea39f85a928ae843703feb (patch)
tree5281c21f17990ae69d685a934847a494cf5245b6 /src/csplit.c
parent4b366ceed572fc4ce706c133ddb79f30f909c805 (diff)
downloadcoreutils-5cd7a18539b3cab460ea39f85a928ae843703feb.tar.xz
(read_input): Rename paramater MAX to MAX_N_BYTES. To avoid potential
conflict with max macro from some system's header files and bad pre-ANSI compilers.
Diffstat (limited to 'src/csplit.c')
-rw-r--r--src/csplit.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/csplit.c b/src/csplit.c
index 5f71de323..9fbf0e35f 100644
--- a/src/csplit.c
+++ b/src/csplit.c
@@ -286,20 +286,20 @@ save_to_hold_area (start, num)
hold_count = num;
}
/* Read up to MAX chars from the input stream into DEST.
Return the number of chars read. */
static int
-read_input (dest, max)
+read_input (dest, max_n_bytes)
char *dest;
- unsigned int max;
+ unsigned int max_n_bytes;
{
int bytes_read;
- if (max == 0)
+ if (max_n_bytes == 0)
return 0;
- bytes_read = safe_read (input_desc, dest, max);
+ bytes_read = safe_read (input_desc, dest, max_n_bytes);
if (bytes_read == 0)
have_read_eof = TRUE;
@@ -286,20 +286,20 @@ save_to_hold_area (start, num)
hold_count = num;
}
-/* Read up to MAX chars from the input stream into DEST.
+/* Read up to MAX_N_BYTES chars from the input stream into DEST.
Return the number of chars read. */
static int